==> haskell-tasty-rerun-1.1.18-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-rerun
version:              1.1.18
visibility:           public
id:                   tasty-rerun-1.1.18-Anb9CkbA0Nh2ThTn3B17Ke
key:                  tasty-rerun-1.1.18-Anb9CkbA0Nh2ThTn3B17Ke
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  cfbd31761a033cc4e4ac8085b368db61
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-8.10.4/site-local/tasty-rerun-1.1.18
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tasty-rerun-1.1.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/tasty-rerun-1.1.18
hs-libraries:         HStasty-rerun-1.1.18-Anb9CkbA0Nh2ThTn3B17Ke
depends:
    base-4.14.1.0 containers-0.6.2.1 mtl-2.2.2
    optparse-applicative-0.16.1.0-B9DBBvhrbFt7Di04tN5A7U
    split-0.2.3.4-E3jU0D5hgj32pJXLxLegYv stm-2.5.0.0
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C
    tasty-1.4.1-HQk70L9hAdzHVPLSaLo7S6 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-rerun-1.1.18-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-rerun
version:              1.1.18
visibility:           public
id:                   tasty-rerun-1.1.18-BQ1hZIQoCvxADO0zgslx1f
key:                  tasty-rerun-1.1.18-BQ1hZIQoCvxADO0zgslx1f
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  15cd5386131413eda8339eff2ed6745f
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-8.10.4/site-local/tasty-rerun-1.1.18
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tasty-rerun-1.1.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/tasty-rerun-1.1.18
hs-libraries:         HStasty-rerun-1.1.18-BQ1hZIQoCvxADO0zgslx1f
depends:
    base-4.14.1.0 containers-0.6.2.1 mtl-2.2.2
    optparse-applicative-0.16.1.0-6y3zD6TyO6A9VMFxY2QvSJ
    split-0.2.3.4-3E8emuJDhtMD2sigAXQm8 stm-2.5.0.0
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C
    tasty-1.4.1-JwKDUajOVuXC2JE9LJpdmc transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
